==> jasperreports_3.7.0%2Bdfsg.orig.tar.gz: jasperreports-3.7.0.orig/src/net/sf/jasperreports/engine/util/JRGraphEnvInitializer.java <==
/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.jasperreports.engine.util;

import java.awt.GraphicsEnvironment;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;

import net.sf.jasperreports.engine.JRRuntimeException;


/**
 * @author Teodor Danciu (teodord@users.sourceforge.net)
 * @version $Id: JRGraphEnvInitializer.java 3053 2009-09-18 12:33:03Z teodord $
 */
public class JRGraphEnvInitializer
{

	/**
	 *
	 */
	private static Set AVAILABLE_FONT_FACE_NAMES = null;

	/**
	 *
	 */
	public static void initializeGraphEnv()
	{
		if (AVAILABLE_FONT_FACE_NAMES == null)
		{
			AVAILABLE_FONT_FACE_NAMES = new HashSet();

			try
			{
				AVAILABLE_FONT_FACE_NAMES.addAll(
					Arrays.asList(GraphicsEnvironment.getLocalGraphicsEnvironment().getAvailableFontFamilyNames())
					);
			}
			catch(Exception e)
			{
				throw new JRRuntimeException("Error initializing graphic environment.", e);
			}
		}
	}

	/**
	 *
	 */
	public static boolean isAwtFontAvailable(String font)
	{
		initializeGraphEnv();
		
		return AVAILABLE_FONT_FACE_NAMES.contains(font);//FIXMEFONT not sure if we should check families or fonts
	}

}

==> jasperreports3.7_3.7.4%2Bdfsg.orig.tar.gz: jasperreports3.7-3.7.4.orig/src/net/sf/jasperreports/engine/util/JRGraphEnvInitializer.java <==
/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.jasperreports.engine.util;

import java.awt.GraphicsEnvironment;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;

import net.sf.jasperreports.engine.JRRuntimeException;


/**
 * @author Teodor Danciu (teodord@users.sourceforge.net)
 * @version $Id: JRGraphEnvInitializer.java 3767 2010-04-26 11:40:09Z lucianc $
 */
public final class JRGraphEnvInitializer
{

	/**
	 *
	 */
	private static Set AVAILABLE_FONT_FACE_NAMES = null; //NOPMD

	/**
	 *
	 */
	public static synchronized void initializeGraphEnv()
	{
		if (AVAILABLE_FONT_FACE_NAMES == null)
		{
			AVAILABLE_FONT_FACE_NAMES = new HashSet();

			try
			{
				AVAILABLE_FONT_FACE_NAMES.addAll(
					Arrays.asList(GraphicsEnvironment.getLocalGraphicsEnvironment().getAvailableFontFamilyNames())
					);
			}
			catch(Exception e)
			{
				throw new JRRuntimeException("Error initializing graphic environment.", e);
			}
		}
	}

	/**
	 *
	 */
	public static boolean isAwtFontAvailable(String font)
	{
		initializeGraphEnv();
		
		return AVAILABLE_FONT_FACE_NAMES.contains(font);//FIXMEFONT not sure if we should check families or fonts
	}

	
	private JRGraphEnvInitializer()
	{
	}
}
